@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Artist;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.22';
+our $VERSION = '0.90';
 
 =head1 NAME
 
@@ -35,15 +35,25 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 release_list()
 
+=head2 release_group_list()
+
 =head2 relation_list()
 
 =head2 relation_lists()
 
+=head2 tag_list()
+
+=head2 user_tag_list()
+
+=head2 rating()
+
+=head2 user_rating()
+
 =head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_begin life_span_end alias_list release_list relation_list relation_lists score/);
+__PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_begin life_span_end alias_list release_list release_group_list relation_list relation_lists tag_list user_tag_list rating user_rating score/);
 
 =head1 AUTHOR
 
@@ -55,7 +65,7 @@ __PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_beg
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2007 by Bob Faist
+Copyright 2006-2009 by Bob Faist
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
