@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Track;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.21';
+our $VERSION = '0.90';
 
 =head1 NAME
 
@@ -31,11 +31,21 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 relation_list()
 
+=head2 relation_lists()
+
+=head2 tag_list()
+
+=head2 user_tag_list()
+
+=head2 rating()
+
+=head2 user_rating()
+
 =head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/id title duration artist release_list puid_list relation_list score/);
+__PACKAGE__->mk_accessors(qw/id title duration isrc_list artist release_list puid_list relation_list relation_lists tag_list user_tag_list rating user_rating score/);
 
 =head1 AUTHOR
 
@@ -47,7 +57,7 @@ __PACKAGE__->mk_accessors(qw/id title duration artist release_list puid_list rel
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2007 by Bob Faist
+Copyright 2006-2009 by Bob Faist
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
