@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Track;
 use strict;
 use WebService::MusicBrainz::Query;
 
-our $VERSION = '0.22';
+our $VERSION = '0.90';
 
 =head1 NAME
 
@@ -41,7 +41,7 @@ sub new {
 
    bless $self, $class;
 
-   $self->_init();
+   $self->_init(@_);
 
    return $self;
 }
@@ -49,9 +49,9 @@ sub new {
 sub _init {
    my $self = shift;
 
-   my $q = WebService::MusicBrainz::Query->new();
+   my $q = WebService::MusicBrainz::Query->new(@_);
 
-   $q->set_url_params(qw/mbid title artist release duration tracknum artistid releaseid puid limit offset/);
+   $q->set_url_params(qw/mbid title artist release duration tracknum artistid releaseid puid limit offset query/);
    $q->set_inc_params(qw/artist releases puids artist-rels release-rels track-rels url-rels/);
 
    $self->{_query} = $q;
